@@ -1,4 +1,4 @@
-import { Cell, Optional } from '@ephox/katamari';
+import { Cell, Singleton } from '@ephox/katamari';
 
 import { nuState } from '../common/BehaviourState';
 import { DockingConfig, DockingMode, DockingState, InitialDockingPosition } from './DockingTypes';
@@ -6,7 +6,7 @@ import { DockingConfig, DockingMode, DockingState, InitialDockingPosition } from
 const init = (spec: DockingConfig): DockingState => {
   const docked = Cell(false);
   const visible = Cell(true);
-  const initialBounds = Cell(Optional.none<InitialDockingPosition>());
+  const initialBounds = Singleton.value<InitialDockingPosition>();
   const modes = Cell<DockingMode[]>(spec.modes);
 
   const readState = () => `docked:  ${docked.get()}, visible: ${visible.get()}, modes: ${modes.get().join(',')}`;
@@ -14,8 +14,9 @@ const init = (spec: DockingConfig): DockingState => {
   return nuState({
     isDocked: docked.get,
     setDocked: docked.set,
-    getInitialPosition: initialBounds.get,
-    setInitialPosition: initialBounds.set,
+    getInitialPos: initialBounds.get,
+    setInitialPos: initialBounds.set,
+    clearInitialPos: initialBounds.clear,
     isVisible: visible.get,
     setVisible: visible.set,
     getModes: modes.get,
