@@ -1,13 +1,13 @@
-import { FieldSchema, ValueSchema } from '@ephox/boulder';
+import { FieldSchema, StructureSchema } from '@ephox/boulder';
 import { Height, SugarElement, Width } from '@ephox/sugar';
 
 import * as Fields from '../../data/Fields';
 
 export default [
-  FieldSchema.strict('closedClass'),
-  FieldSchema.strict('openClass'),
-  FieldSchema.strict('shrinkingClass'),
-  FieldSchema.strict('growingClass'),
+  FieldSchema.required('closedClass'),
+  FieldSchema.required('openClass'),
+  FieldSchema.required('shrinkingClass'),
+  FieldSchema.required('growingClass'),
 
   // Element which shrinking and growing animations
   FieldSchema.option('getAnimationRoot'),
@@ -17,7 +17,7 @@ export default [
   Fields.onHandler('onGrown'),
   Fields.onHandler('onStartGrow'),
   FieldSchema.defaulted('expanded', false),
-  FieldSchema.strictOf('dimension', ValueSchema.choose(
+  FieldSchema.requiredOf('dimension', StructureSchema.choose(
     'property', {
       width: [
         Fields.output('property', 'width'),
