@@ -1,4 +1,4 @@
-import { FieldSchema, ValueSchema } from '@ephox/boulder';
+import { FieldSchema, StructureSchema } from '@ephox/boulder';
 import { Throttler } from '@ephox/katamari';
 
 import { AlloyComponent } from '../../api/component/ComponentApi';
@@ -21,11 +21,11 @@ const setup = (streamInfo: StreamingConfig, streamState: StreamingStateType) =>
 };
 
 export default [
-  FieldSchema.strictOf('stream', ValueSchema.choose(
+  FieldSchema.requiredOf('stream', StructureSchema.choose(
     'mode',
     {
       throttle: [
-        FieldSchema.strict('delay'),
+        FieldSchema.required('delay'),
         FieldSchema.defaulted('stopEvent', true),
         Fields.output('streams', {
           setup,
