@@ -4,10 +4,10 @@ import * as Boxes from '../../alien/Boxes';
 import * as Fields from '../../data/Fields';
 
 export default FieldSchema.optionObjOf('snaps', [
-  FieldSchema.strict('getSnapPoints'),
+  FieldSchema.required('getSnapPoints'),
   Fields.onHandler('onSensor'),
-  FieldSchema.strict('leftAttr'),
-  FieldSchema.strict('topAttr'),
+  FieldSchema.required('leftAttr'),
+  FieldSchema.required('topAttr'),
   FieldSchema.defaulted('lazyViewport', Boxes.win),
   FieldSchema.defaulted('mustSnap', false)
 ]);
\ No newline at end of file
