@@ -1,5 +1,6 @@
-import { ValueSchema } from '@ephox/boulder';
+import { StructureSchema, ValueType } from '@ephox/boulder';
 import { Result } from '@ephox/katamari';
+
 import { FormComponentWithLabel, formComponentWithLabelFields, FormComponentWithLabelSpec } from './FormComponent';
 
 export interface ColorInputSpec extends FormComponentWithLabelSpec {
@@ -12,9 +13,9 @@ export interface ColorInput extends FormComponentWithLabel {
 
 const colorInputFields = formComponentWithLabelFields;
 
-export const colorInputSchema = ValueSchema.objOf(colorInputFields);
+export const colorInputSchema = StructureSchema.objOf(colorInputFields);
 
-export const colorInputDataProcessor = ValueSchema.string;
+export const colorInputDataProcessor = ValueType.string;
 
-export const createColorInput = (spec: ColorInputSpec): Result<ColorInput, ValueSchema.SchemaError<any>> =>
-  ValueSchema.asRaw<ColorInput>('colorinput', colorInputSchema, spec);
+export const createColorInput = (spec: ColorInputSpec): Result<ColorInput, StructureSchema.SchemaError<any>> =>
+  StructureSchema.asRaw<ColorInput>('colorinput', colorInputSchema, spec);
