@@ -1,5 +1,6 @@
-import { FieldProcessorAdt, FieldSchema, ValueSchema } from '@ephox/boulder';
+import { FieldProcessor, FieldSchema, StructureSchema, ValueType } from '@ephox/boulder';
 import { Result } from '@ephox/katamari';
+
 import { FormComponentWithLabel, formComponentWithLabelFields, FormComponentWithLabelSpec } from './FormComponent';
 
 export interface SelectBoxItemSpec {
@@ -26,18 +27,18 @@ export interface SelectBox extends FormComponentWithLabel {
   disabled: boolean;
 }
 
-const selectBoxFields: FieldProcessorAdt[] = formComponentWithLabelFields.concat([
-  FieldSchema.strictArrayOfObj('items', [
-    FieldSchema.strictString('text'),
-    FieldSchema.strictString('value')
+const selectBoxFields: FieldProcessor[] = formComponentWithLabelFields.concat([
+  FieldSchema.requiredArrayOfObj('items', [
+    FieldSchema.requiredString('text'),
+    FieldSchema.requiredString('value')
   ]),
   FieldSchema.defaultedNumber('size', 1),
   FieldSchema.defaultedBoolean('disabled', false)
 ]);
 
-export const selectBoxSchema = ValueSchema.objOf(selectBoxFields);
+export const selectBoxSchema = StructureSchema.objOf(selectBoxFields);
 
-export const selectBoxDataProcessor = ValueSchema.string;
+export const selectBoxDataProcessor = ValueType.string;
 
-export const createSelectBox = (spec: SelectBoxSpec): Result<SelectBox, ValueSchema.SchemaError<any>> =>
-  ValueSchema.asRaw<SelectBox>('selectbox', selectBoxSchema, spec);
+export const createSelectBox = (spec: SelectBoxSpec): Result<SelectBox, StructureSchema.SchemaError<any>> =>
+  StructureSchema.asRaw<SelectBox>('selectbox', selectBoxSchema, spec);
