@@ -3,7 +3,7 @@ import * as Arr from './Arr';
 import { Future } from './Future';
 
 export const par = <T>(futures: ArrayLike<Future<T>>): Future<Array<T>> =>
-  AsyncValues.par(futures, Future.nu);
+  AsyncValues.par<Future<T>, T, Future<Array<T>>>(futures, Future.nu);
 
 export const traverse = <A, B>(array: ArrayLike<A>, fn: (value: A) => Future<B>): Future<B[]> =>
   par(Arr.map(array, fn));
