@@ -6,9 +6,10 @@
  */
 
 import { Arr } from '@ephox/katamari';
+
 import Editor from 'tinymce/core/api/Editor';
 
-export const setup = (editor: Editor) => {
+export const setup = (editor: Editor): void => {
   editor.on('PreInit', () => {
     editor.parser.addAttributeFilter('data-emoticon', (nodes) => {
       Arr.each(nodes, (node) => {
