@@ -9,9 +9,11 @@ import { Arr, Fun, Optional, Strings } from '@ephox/katamari';
 
 import { EmojiEntry } from './EmojiDatabase';
 
-const emojiMatches = (emoji: EmojiEntry, lowerCasePattern: string): boolean => Strings.contains(emoji.title.toLowerCase(), lowerCasePattern) || Arr.exists(emoji.keywords, (k) => Strings.contains(k.toLowerCase(), lowerCasePattern));
+const emojiMatches = (emoji: EmojiEntry, lowerCasePattern: string): boolean =>
+  Strings.contains(emoji.title.toLowerCase(), lowerCasePattern) ||
+  Arr.exists(emoji.keywords, (k) => Strings.contains(k.toLowerCase(), lowerCasePattern));
 
-const emojisFrom = (list: EmojiEntry[], pattern: string, maxResults: Optional<number>): Array<{value: string; icon: string; text: string }> => {
+const emojisFrom = (list: EmojiEntry[], pattern: string, maxResults: Optional<number>): Array<{ value: string; icon: string; text: string }> => {
   const matches = [];
   const lowerCasePattern = pattern.toLowerCase();
   const reachedLimit = maxResults.fold(() => Fun.never, (max) => (size) => size >= max);
