@@ -6,9 +6,10 @@
  */
 
 import Editor from 'tinymce/core/api/Editor';
+
 import * as Settings from '../api/Settings';
 
-const setup = (editor: Editor) => {
+const setup = (editor: Editor): void => {
   const plugin = editor.plugins.paste;
 
   const preProcess = Settings.getPreProcess(editor);
