@@ -7,17 +7,19 @@
 
 import Editor from 'tinymce/core/api/Editor';
 
-const register = (editor: Editor) => {
+const register = (editor: Editor): void => {
+  const onAction = () => editor.execCommand('mcePreview');
+
   editor.ui.registry.addButton('preview', {
     icon: 'preview',
     tooltip: 'Preview',
-    onAction: () => editor.execCommand('mcePreview')
+    onAction
   });
 
   editor.ui.registry.addMenuItem('preview', {
     icon: 'preview',
     text: 'Preview',
-    onAction: () => editor.execCommand('mcePreview')
+    onAction
   });
 };
 
