@@ -6,7 +6,9 @@
  */
 
 import { Cell } from '@ephox/katamari';
+
 import Editor from 'tinymce/core/api/Editor';
+
 import * as Actions from '../core/Actions';
 import { DomTextMatcher } from '../core/DomTextMatcher';
 import * as Settings from './Settings';
@@ -14,7 +16,14 @@ import * as Settings from './Settings';
 type LastSuggestion = Actions.LastSuggestion;
 type Data = Actions.Data;
 
-const get = (editor: Editor, startedState: Cell<boolean>, lastSuggestionsState: Cell<LastSuggestion>, textMatcherState: Cell<DomTextMatcher>, currentLanguageState: Cell<string>, _url: string) => {
+export interface Api {
+  readonly getTextMatcher: () => DomTextMatcher;
+  readonly getWordCharPattern: () => RegExp;
+  readonly markErrors: (data: Data) => void;
+  readonly getLanguage: () => string;
+}
+
+const get = (editor: Editor, startedState: Cell<boolean>, lastSuggestionsState: Cell<LastSuggestion>, textMatcherState: Cell<DomTextMatcher>, currentLanguageState: Cell<string>): Api => {
   const getWordCharPattern = () => {
     return Settings.getSpellcheckerWordcharPattern(editor);
   };
