@@ -7,9 +7,8 @@
 
 import Editor from 'tinymce/core/api/Editor';
 
-const isEnabledByDefault = (editor: Editor) => {
-  return editor.getParam('visualblocks_default_state', false, 'boolean');
-};
+const isEnabledByDefault = (editor: Editor): boolean =>
+  editor.getParam('visualblocks_default_state', false, 'boolean');
 
 export {
   isEnabledByDefault
