@@ -6,12 +6,13 @@
  */
 
 import { Cell } from '@ephox/katamari';
+
 import Editor from 'tinymce/core/api/Editor';
 
 import * as Events from '../api/Events';
 import * as VisualChars from './VisualChars';
 
-const applyVisualChars = (editor: Editor, toggleState: Cell<boolean>) => {
+const applyVisualChars = (editor: Editor, toggleState: Cell<boolean>): void => {
   Events.fireVisualChars(editor, toggleState.get());
 
   const body = editor.getBody();
@@ -23,7 +24,7 @@ const applyVisualChars = (editor: Editor, toggleState: Cell<boolean>) => {
 };
 
 // Toggle state and save selection bookmark before applying visualChars
-const toggleVisualChars = (editor: Editor, toggleState: Cell<boolean>) => {
+const toggleVisualChars = (editor: Editor, toggleState: Cell<boolean>): void => {
   toggleState.set(!toggleState.get());
 
   const bookmark = editor.selection.getBookmark();
